/*
 * Automatically generated C config: don't edit
 */
#define AUTOCONF_INCLUDED
#define CONFIG_UID16 1
#define CONFIG_HIGHMEM 1

/*
 * Code maturity level options
 */
#define CONFIG_EXPERIMENTAL 1

/*
 * Loadable module support
 */
#define CONFIG_MODULES 1
#define CONFIG_MODVERSIONS 1
#define CONFIG_KMOD 1

/*
 * General setup
 */
#define CONFIG_VT 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_SMP 1
#define CONFIG_NR_CPUS (2)
#define CONFIG_SPARC32 1
#undef  CONFIG_ISA
#undef  CONFIG_EISA
#undef  CONFIG_MCA
#undef  CONFIG_PCMCIA
#define CONFIG_SBUS 1
#define CONFIG_SBUSCHAR 1
#define CONFIG_BUSMOUSE 1
#define CONFIG_SUN_MOUSE 1
#define CONFIG_SERIAL 1
#define CONFIG_SUN_SERIAL 1
#define CONFIG_SERIAL_CONSOLE 1
#define CONFIG_SUN_KEYBOARD 1
#define CONFIG_SUN_CONSOLE 1
#define CONFIG_SUN_AUXIO 1
#define CONFIG_SUN_IO 1
#define CONFIG_RWSEM_GENERIC_SPINLOCK 1
#undef  CONFIG_RWSEM_XCHGADD_ALGORITHM
#define CONFIG_SUN_PM 1
#undef  CONFIG_SUN4
#undef  CONFIG_PCI
#undef  CONFIG_SUN_OPENPROMFS
#define CONFIG_SUN_OPENPROMFS_MODULE 1
#define CONFIG_NET 1
#define CONFIG_SYSVIPC 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_SYSCTL 1
#define CONFIG_KCORE_ELF 1
#undef  CONFIG_BINFMT_AOUT
#define CONFIG_BINFMT_AOUT_MODULE 1
#define CONFIG_BINFMT_ELF 1
#undef  CONFIG_BINFMT_MISC
#define CONFIG_BINFMT_MISC_MODULE 1
#undef  CONFIG_SUNOS_EMUL
#undef  CONFIG_OOM_KILLER

/*
 * Parallel port support
 */
#undef  CONFIG_PARPORT
#define CONFIG_PARPORT_MODULE 1
#undef  CONFIG_PARPORT_PC
#undef  CONFIG_PARPORT_AMIGA
#undef  CONFIG_PARPORT_MFC3
#undef  CONFIG_PARPORT_ATARI
#undef  CONFIG_PARPORT_GSC
#undef  CONFIG_PARPORT_SUNBPP
#define CONFIG_PARPORT_SUNBPP_MODULE 1
#undef  CONFIG_PARPORT_IP22
#undef  CONFIG_PARPORT_OTHER
#undef  CONFIG_PARPORT_1284
#undef  CONFIG_PRINTER
#define CONFIG_PRINTER_MODULE 1

/*
 * Console drivers
 */
#define CONFIG_PROM_CONSOLE 1

/*
 * Frame-buffer support
 */
#define CONFIG_FB 1
#define CONFIG_DUMMY_CONSOLE 1
#undef  CONFIG_FB_CYBER2000
#define CONFIG_FB_SBUS 1
#define CONFIG_FB_CGSIX 1
#define CONFIG_FB_BWTWO 1
#define CONFIG_FB_CGTHREE 1
#define CONFIG_FB_TCX 1
#define CONFIG_FB_CGFOURTEEN 1
#undef  CONFIG_FB_P9100
#define CONFIG_FB_LEO 1
#undef  CONFIG_FB_VIRTUAL
#define CONFIG_FBCON_ADVANCED 1
#define CONFIG_FBCON_MFB 1
#undef  CONFIG_FBCON_CFB2
#undef  CONFIG_FBCON_CFB4
#define CONFIG_FBCON_CFB8 1
#undef  CONFIG_FBCON_CFB16
#define CONFIG_FBCON_CFB16_MODULE 1
#undef  CONFIG_FBCON_CFB24
#define CONFIG_FBCON_CFB24_MODULE 1
#undef  CONFIG_FBCON_CFB32
#define CONFIG_FBCON_CFB32_MODULE 1
#undef  CONFIG_FBCON_AFB
#undef  CONFIG_FBCON_ILBM
#undef  CONFIG_FBCON_IPLAN2P2
#undef  CONFIG_FBCON_IPLAN2P4
#undef  CONFIG_FBCON_IPLAN2P8
#undef  CONFIG_FBCON_MAC
#undef  CONFIG_FBCON_VGA_PLANES
#undef  CONFIG_FBCON_VGA
#define CONFIG_FBCON_VGA_MODULE 1
#undef  CONFIG_FBCON_HGA
#define CONFIG_FBCON_FONTWIDTH8_ONLY 1
#define CONFIG_FONT_SUN8x16 1
#define CONFIG_FBCON_FONTS 1
#undef  CONFIG_FONT_8x8
#define CONFIG_FONT_8x16 1
#undef  CONFIG_FONT_PEARL_8x8
#undef  CONFIG_FONT_ACORN_8x8

/*
 * Memory Technology Devices (MTD)
 */
#undef  CONFIG_MTD

/*
 * Misc Linux/SPARC drivers
 */
#undef  CONFIG_SUN_OPENPROMIO
#define CONFIG_SUN_OPENPROMIO_MODULE 1
#define CONFIG_SUN_MOSTEK_RTC 1
#undef  CONFIG_SUN_BPP
#undef  CONFIG_SUN_VIDEOPIX
#undef  CONFIG_SUN_AURORA
#undef  CONFIG_TADPOLE_TS102_UCTRL
#undef  CONFIG_SUN_JSFLASH

/*
 * Linux/SPARC audio subsystem (EXPERIMENTAL)
 */
#undef  CONFIG_SPARCAUDIO
#define CONFIG_SPARCAUDIO_MODULE 1
#undef  CONFIG_SPARCAUDIO_AMD7930
#define CONFIG_SPARCAUDIO_AMD7930_MODULE 1
#undef  CONFIG_SPARCAUDIO_DBRI
#define CONFIG_SPARCAUDIO_DBRI_MODULE 1
#undef  CONFIG_SPARCAUDIO_CS4231
#define CONFIG_SPARCAUDIO_CS4231_MODULE 1
#undef  CONFIG_SPARCAUDIO_DUMMY

/*
 * Block devices
 */
#define CONFIG_BLK_DEV_FD 1
#undef  CONFIG_BLK_DEV_LOOP
#define CONFIG_BLK_DEV_LOOP_MODULE 1
#undef  CONFIG_BLK_DEV_NBD
#define CONFIG_BLK_DEV_NBD_MODULE 1

/*
 * Multi-device support (RAID and LVM)
 */
#define CONFIG_MD 1
#define CONFIG_BLK_DEV_MD 1
#undef  CONFIG_MD_LINEAR
#define CONFIG_MD_LINEAR_MODULE 1
#undef  CONFIG_MD_RAID0
#define CONFIG_MD_RAID0_MODULE 1
#define CONFIG_MD_RAID1 1
#define CONFIG_MD_RAID5 1
#undef  CONFIG_MD_MULTIPATH
#define CONFIG_MD_MULTIPATH_MODULE 1
#undef  CONFIG_BLK_DEV_LVM
#define CONFIG_BLK_DEV_LVM_MODULE 1
#define CONFIG_BLK_DEV_RAM 1
#define CONFIG_BLK_DEV_RAM_SIZE (8192)
#define CONFIG_BLK_DEV_INITRD 1

/*
 * Networking options
 */
#define CONFIG_PACKET 1
#undef  CONFIG_PACKET_MMAP
#define CONFIG_NETLINK_DEV 1
#define CONFIG_NETFILTER 1
#undef  CONFIG_NETFILTER_DEBUG
#define CONFIG_FILTER 1
#define CONFIG_UNIX 1
#define CONFIG_INET 1
#undef  CONFIG_IP_MULTICAST
#undef  CONFIG_IP_ADVANCED_ROUTER
#undef  CONFIG_IP_PNP
#undef  CONFIG_NET_IPIP
#define CONFIG_NET_IPIP_MODULE 1
#undef  CONFIG_NET_IPGRE
#define CONFIG_NET_IPGRE_MODULE 1
#undef  CONFIG_ARPD
#undef  CONFIG_INET_ECN
#undef  CONFIG_SYN_COOKIES

/*
 *   IP: Netfilter Configuration
 */
#undef  CONFIG_IP_NF_CONNTRACK
#define CONFIG_IP_NF_CONNTRACK_MODULE 1
#undef  CONFIG_IP_NF_FTP
#define CONFIG_IP_NF_FTP_MODULE 1
#undef  CONFIG_IP_NF_AMANDA
#define CONFIG_IP_NF_AMANDA_MODULE 1
#undef  CONFIG_IP_NF_TFTP
#define CONFIG_IP_NF_TFTP_MODULE 1
#undef  CONFIG_IP_NF_IRC
#define CONFIG_IP_NF_IRC_MODULE 1
#undef  CONFIG_IP_NF_QUEUE
#define CONFIG_IP_NF_QUEUE_MODULE 1
#undef  CONFIG_IP_NF_IPTABLES
#define CONFIG_IP_NF_IPTABLES_MODULE 1
#undef  CONFIG_IP_NF_MATCH_LIMIT
#define CONFIG_IP_NF_MATCH_LIMIT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MAC
#define CONFIG_IP_NF_MATCH_MAC_MODULE 1
#undef  CONFIG_IP_NF_MATCH_PKTTYPE
#define CONFIG_IP_NF_MATCH_PKTTYPE_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MARK
#define CONFIG_IP_NF_MATCH_MARK_MODULE 1
#undef  CONFIG_IP_NF_MATCH_MULTIPORT
#define CONFIG_IP_NF_MATCH_MULTIPORT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TOS
#define CONFIG_IP_NF_MATCH_TOS_MODULE 1
#undef  CONFIG_IP_NF_MATCH_RECENT
#define CONFIG_IP_NF_MATCH_RECENT_MODULE 1
#undef  CONFIG_IP_NF_MATCH_ECN
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#undef  CONFIG_IP_NF_MATCH_DSCP
#define CONFIG_IP_NF_MATCH_DSCP_MODULE 1
#undef  CONFIG_IP_NF_MATCH_AH_ESP
#define CONFIG_IP_NF_MATCH_AH_ESP_MODULE 1
#undef  CONFIG_IP_NF_MATCH_LENGTH
#define CONFIG_IP_NF_MATCH_LENGTH_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TTL
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#undef  CONFIG_IP_NF_MATCH_TCPMSS
#define CONFIG_IP_NF_MATCH_TCPMSS_MODULE 1
#undef  CONFIG_IP_NF_MATCH_HELPER
#define CONFIG_IP_NF_MATCH_HELPER_MODULE 1
#undef  CONFIG_IP_NF_MATCH_STATE
#define CONFIG_IP_NF_MATCH_STATE_MODULE 1
#undef  CONFIG_IP_NF_MATCH_CONNTRACK
#define CONFIG_IP_NF_MATCH_CONNTRACK_MODULE 1
#undef  CONFIG_IP_NF_MATCH_UNCLEAN
#define CONFIG_IP_NF_MATCH_UNCLEAN_MODULE 1
#undef  CONFIG_IP_NF_MATCH_OWNER
#define CONFIG_IP_NF_MATCH_OWNER_MODULE 1
#undef  CONFIG_IP_NF_FILTER
#define CONFIG_IP_NF_FILTER_MODULE 1
#undef  CONFIG_IP_NF_TARGET_REJECT
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#undef  CONFIG_IP_NF_TARGET_MIRROR
#define CONFIG_IP_NF_TARGET_MIRROR_MODULE 1
#undef  CONFIG_IP_NF_NAT
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_IP_NF_NAT_NEEDED 1
#undef  CONFIG_IP_NF_TARGET_MASQUERADE
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#undef  CONFIG_IP_NF_TARGET_REDIRECT
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#undef  CONFIG_IP_NF_NAT_AMANDA
#define CONFIG_IP_NF_NAT_AMANDA_MODULE 1
#undef  CONFIG_IP_NF_NAT_SNMP_BASIC
#define CONFIG_IP_NF_NAT_SNMP_BASIC_MODULE 1
#undef  CONFIG_IP_NF_NAT_IRC
#define CONFIG_IP_NF_NAT_IRC_MODULE 1
#undef  CONFIG_IP_NF_NAT_FTP
#define CONFIG_IP_NF_NAT_FTP_MODULE 1
#undef  CONFIG_IP_NF_NAT_TFTP
#define CONFIG_IP_NF_NAT_TFTP_MODULE 1
#undef  CONFIG_IP_NF_MANGLE
#define CONFIG_IP_NF_MANGLE_MODULE 1
#undef  CONFIG_IP_NF_TARGET_TOS
#define CONFIG_IP_NF_TARGET_TOS_MODULE 1
#undef  CONFIG_IP_NF_TARGET_ECN
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#undef  CONFIG_IP_NF_TARGET_DSCP
#define CONFIG_IP_NF_TARGET_DSCP_MODULE 1
#undef  CONFIG_IP_NF_TARGET_MARK
#define CONFIG_IP_NF_TARGET_MARK_MODULE 1
#undef  CONFIG_IP_NF_TARGET_LOG
#define CONFIG_IP_NF_TARGET_LOG_MODULE 1
#undef  CONFIG_IP_NF_TARGET_ULOG
#define CONFIG_IP_NF_TARGET_ULOG_MODULE 1
#undef  CONFIG_IP_NF_TARGET_TCPMSS
#define CONFIG_IP_NF_TARGET_TCPMSS_MODULE 1
#undef  CONFIG_IP_NF_ARPTABLES
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#undef  CONFIG_IP_NF_ARPFILTER
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#undef  CONFIG_IP_NF_ARP_MANGLE
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1
#undef  CONFIG_IP_NF_COMPAT_IPCHAINS
#undef  CONFIG_IP_NF_COMPAT_IPFWADM

/*
 *   IP: Virtual Server Configuration
 */
#undef  CONFIG_IP_VS
#undef  CONFIG_IPV6
#undef  CONFIG_KHTTPD

/*
 *    SCTP Configuration (EXPERIMENTAL)
 */
#undef  CONFIG_IP_SCTP
#define CONFIG_IP_SCTP_MODULE 1
#undef  CONFIG_SCTP_DBG_MSG
#undef  CONFIG_SCTP_DBG_OBJCNT
#undef  CONFIG_SCTP_HMAC_NONE
#define CONFIG_SCTP_HMAC_SHA1 1
#undef  CONFIG_SCTP_HMAC_MD5
#undef  CONFIG_ATM
#undef  CONFIG_VLAN_8021Q
#define CONFIG_VLAN_8021Q_MODULE 1

/*
 *  
 */
#undef  CONFIG_IPX
#undef  CONFIG_ATALK
#undef  CONFIG_DECNET
#undef  CONFIG_BRIDGE
#define CONFIG_BRIDGE_MODULE 1
#undef  CONFIG_X25
#undef  CONFIG_LAPB
#undef  CONFIG_LLC
#undef  CONFIG_NET_DIVERT
#undef  CONFIG_ECONET
#undef  CONFIG_WAN_ROUTER
#undef  CONFIG_NET_FASTROUTE
#undef  CONFIG_NET_HW_FLOWCONTROL

/*
 * QoS and/or fair queueing
 */
#undef  CONFIG_NET_SCHED

/*
 * Network testing
 */
#undef  CONFIG_NET_PKTGEN
#undef  CONFIG_IDE
#undef  CONFIG_BLK_DEV_HD

/*
 * ISDN subsystem
 */
#undef  CONFIG_ISDN

/*
 * SCSI support
 */
#define CONFIG_SCSI 1

/*
 * SCSI support type (disk, tape, CDrom)
 */
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_SD_EXTRA_DEVS (40)
#undef  CONFIG_CHR_DEV_ST
#define CONFIG_CHR_DEV_ST_MODULE 1
#undef  CONFIG_CHR_DEV_OSST
#define CONFIG_BLK_DEV_SR 1
#undef  CONFIG_BLK_DEV_SR_VENDOR
#define CONFIG_SR_EXTRA_DEVS (2)
#undef  CONFIG_CHR_DEV_SG
#define CONFIG_CHR_DEV_SG_MODULE 1

/*
 * Some SCSI devices (e.g. CD jukebox) support multiple LUNs
 */
#undef  CONFIG_SCSI_MULTI_LUN
#define CONFIG_SCSI_CONSTANTS 1
#undef  CONFIG_SCSI_LOGGING

/*
 * SCSI low-level drivers
 */
#define CONFIG_SCSI_SUNESP 1
#define CONFIG_SCSI_QLOGICPTI 1

/*
 * Fibre Channel support
 */
#undef  CONFIG_FC4
#define CONFIG_FC4_MODULE 1

/*
 * FC4 drivers
 */
#undef  CONFIG_FC4_SOC
#define CONFIG_FC4_SOC_MODULE 1
#undef  CONFIG_FC4_SOCAL
#define CONFIG_FC4_SOCAL_MODULE 1

/*
 * FC4 targets
 */
#undef  CONFIG_SCSI_PLUTO
#define CONFIG_SCSI_PLUTO_MODULE 1
#undef  CONFIG_SCSI_FCAL
#define CONFIG_SCSI_FCAL_MODULE 1

/*
 * Network device support
 */
#define CONFIG_NETDEVICES 1
#undef  CONFIG_DUMMY
#define CONFIG_DUMMY_MODULE 1
#undef  CONFIG_BONDING
#define CONFIG_BONDING_MODULE 1
#undef  CONFIG_TUN
#define CONFIG_TUN_MODULE 1
#undef  CONFIG_PPP
#define CONFIG_PPP_MODULE 1
#undef  CONFIG_PPP_ASYNC
#define CONFIG_PPP_ASYNC_MODULE 1
#undef  CONFIG_PPP_SYNC_TTY
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#undef  CONFIG_PPP_DEFLATE
#define CONFIG_PPP_DEFLATE_MODULE 1
#undef  CONFIG_PPP_BSDCOMP
#define CONFIG_PPP_BSDCOMP_MODULE 1
#undef  CONFIG_PPPOE
#define CONFIG_PPPOE_MODULE 1
#undef  CONFIG_SLIP
#define CONFIG_SLIP_MODULE 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_SLIP_SMART 1
#define CONFIG_SLIP_MODE_SLIP6 1
#undef  CONFIG_SUNLANCE
#define CONFIG_SUNLANCE_MODULE 1
#undef  CONFIG_HAPPYMEAL
#define CONFIG_HAPPYMEAL_MODULE 1
#undef  CONFIG_SUNBMAC
#define CONFIG_SUNBMAC_MODULE 1
#undef  CONFIG_SUNQE
#define CONFIG_SUNQE_MODULE 1
#undef  CONFIG_MYRI_SBUS
#define CONFIG_MYRI_SBUS_MODULE 1

/*
 * Unix98 PTY support
 */
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_UNIX98_PTY_COUNT (256)

/*
 * File systems
 */
#undef  CONFIG_QUOTA
#undef  CONFIG_QFMT_V2
#undef  CONFIG_AUTOFS_FS
#undef  CONFIG_AUTOFS4_FS
#undef  CONFIG_REISERFS_FS
#define CONFIG_REISERFS_FS_MODULE 1
#undef  CONFIG_REISERFS_CHECK
#undef  CONFIG_REISERFS_PROC_INFO
#undef  CONFIG_ADFS_FS
#undef  CONFIG_ADFS_FS_RW
#undef  CONFIG_AFFS_FS
#undef  CONFIG_HFS_FS
#undef  CONFIG_HFSPLUS_FS
#undef  CONFIG_BEFS_FS
#undef  CONFIG_BEFS_DEBUG
#undef  CONFIG_BFS_FS
#define CONFIG_EXT3_FS 1
#define CONFIG_JBD 1
#undef  CONFIG_JBD_DEBUG
#undef  CONFIG_FAT_FS
#define CONFIG_FAT_FS_MODULE 1
#undef  CONFIG_MSDOS_FS
#define CONFIG_MSDOS_FS_MODULE 1
#undef  CONFIG_UMSDOS_FS
#define CONFIG_UMSDOS_FS_MODULE 1
#undef  CONFIG_VFAT_FS
#define CONFIG_VFAT_FS_MODULE 1
#undef  CONFIG_EFS_FS
#define CONFIG_EFS_FS_MODULE 1
#undef  CONFIG_JFFS_FS
#undef  CONFIG_JFFS2_FS
#undef  CONFIG_CRAMFS
#undef  CONFIG_TMPFS
#define CONFIG_RAMFS 1
#define CONFIG_ISO9660_FS 1
#define CONFIG_JOLIET 1
#undef  CONFIG_ZISOFS
#undef  CONFIG_JFS_FS
#define CONFIG_JFS_FS_MODULE 1
#undef  CONFIG_JFS_DEBUG
#undef  CONFIG_JFS_STATISTICS
#undef  CONFIG_MINIX_FS
#define CONFIG_MINIX_FS_MODULE 1
#undef  CONFIG_VXFS_FS
#undef  CONFIG_NTFS_FS
#define CONFIG_NTFS_FS_MODULE 1
#define CONFIG_NTFS_RW 1
#undef  CONFIG_HPFS_FS
#define CONFIG_HPFS_FS_MODULE 1
#define CONFIG_PROC_FS 1
#undef  CONFIG_DEVFS_FS
#undef  CONFIG_DEVFS_MOUNT
#undef  CONFIG_DEVFS_DEBUG
#define CONFIG_DEVPTS_FS 1
#undef  CONFIG_QNX4FS_FS
#undef  CONFIG_QNX4FS_RW
#undef  CONFIG_ROMFS_FS
#define CONFIG_ROMFS_FS_MODULE 1
#define CONFIG_EXT2_FS 1
#undef  CONFIG_SYSV_FS
#undef  CONFIG_UDF_FS
#undef  CONFIG_UDF_RW
#undef  CONFIG_UFS_FS
#define CONFIG_UFS_FS_MODULE 1
#undef  CONFIG_UFS_FS_WRITE
#undef  CONFIG_XFS_FS
#define CONFIG_XFS_FS_MODULE 1
#undef  CONFIG_XFS_QUOTA
#undef  CONFIG_XFS_RT
#undef  CONFIG_XFS_TRACE
#undef  CONFIG_XFS_DEBUG

/*
 * Network File Systems
 */
#undef  CONFIG_CODA_FS
#define CONFIG_CODA_FS_MODULE 1
#undef  CONFIG_INTERMEZZO_FS
#define CONFIG_INTERMEZZO_FS_MODULE 1
#undef  CONFIG_NFS_FS
#define CONFIG_NFS_FS_MODULE 1
#define CONFIG_NFS_V3 1
#undef  CONFIG_NFS_DIRECTIO
#undef  CONFIG_ROOT_NFS
#undef  CONFIG_NFSD
#define CONFIG_NFSD_MODULE 1
#define CONFIG_NFSD_V3 1
#define CONFIG_NFSD_TCP 1
#undef  CONFIG_SUNRPC
#define CONFIG_SUNRPC_MODULE 1
#undef  CONFIG_LOCKD
#define CONFIG_LOCKD_MODULE 1
#define CONFIG_LOCKD_V4 1
#undef  CONFIG_SMB_FS
#define CONFIG_SMB_FS_MODULE 1
#undef  CONFIG_SMB_NLS_DEFAULT
#undef  CONFIG_SMB_UNIX
#undef  CONFIG_NCP_FS
#undef  CONFIG_NCPFS_PACKET_SIGNING
#undef  CONFIG_NCPFS_IOCTL_LOCKING
#undef  CONFIG_NCPFS_STRONG
#undef  CONFIG_NCPFS_NFS_NS
#undef  CONFIG_NCPFS_OS2_NS
#undef  CONFIG_NCPFS_SMALLDOS
#undef  CONFIG_NCPFS_NLS
#undef  CONFIG_NCPFS_EXTRAS
#undef  CONFIG_ZISOFS_FS

/*
 * Partition Types
 */
#define CONFIG_PARTITION_ADVANCED 1
#undef  CONFIG_ACORN_PARTITION
#undef  CONFIG_OSF_PARTITION
#undef  CONFIG_AMIGA_PARTITION
#undef  CONFIG_ATARI_PARTITION
#undef  CONFIG_MAC_PARTITION
#define CONFIG_MSDOS_PARTITION 1
#undef  CONFIG_BSD_DISKLABEL
#undef  CONFIG_MINIX_SUBPARTITION
#undef  CONFIG_SOLARIS_X86_PARTITION
#undef  CONFIG_UNIXWARE_DISKLABEL
#undef  CONFIG_LDM_PARTITION
#undef  CONFIG_SGI_PARTITION
#undef  CONFIG_ULTRIX_PARTITION
#define CONFIG_SUN_PARTITION 1
#undef  CONFIG_EFI_PARTITION
#define CONFIG_SMB_NLS 1
#define CONFIG_NLS 1

/*
 * Native Language Support
 */
#define CONFIG_NLS_DEFAULT "iso8859-1"
#undef  CONFIG_NLS_CODEPAGE_437
#define CONFIG_NLS_CODEPAGE_437_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_737
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_775
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_850
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_852
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_855
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_857
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_860
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_861
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_862
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_863
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_864
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_865
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_866
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_869
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_936
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_950
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_932
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_949
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_874
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#undef  CONFIG_NLS_ISO8859_8
#define CONFIG_NLS_ISO8859_8_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_1250
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#undef  CONFIG_NLS_CODEPAGE_1251
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#undef  CONFIG_NLS_ISO8859_1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#undef  CONFIG_NLS_ISO8859_2
#define CONFIG_NLS_ISO8859_2_MODULE 1
#undef  CONFIG_NLS_ISO8859_3
#define CONFIG_NLS_ISO8859_3_MODULE 1
#undef  CONFIG_NLS_ISO8859_4
#define CONFIG_NLS_ISO8859_4_MODULE 1
#undef  CONFIG_NLS_ISO8859_5
#define CONFIG_NLS_ISO8859_5_MODULE 1
#undef  CONFIG_NLS_ISO8859_6
#define CONFIG_NLS_ISO8859_6_MODULE 1
#undef  CONFIG_NLS_ISO8859_7
#define CONFIG_NLS_ISO8859_7_MODULE 1
#undef  CONFIG_NLS_ISO8859_9
#define CONFIG_NLS_ISO8859_9_MODULE 1
#undef  CONFIG_NLS_ISO8859_13
#define CONFIG_NLS_ISO8859_13_MODULE 1
#undef  CONFIG_NLS_ISO8859_14
#define CONFIG_NLS_ISO8859_14_MODULE 1
#undef  CONFIG_NLS_ISO8859_15
#define CONFIG_NLS_ISO8859_15_MODULE 1
#undef  CONFIG_NLS_KOI8_R
#define CONFIG_NLS_KOI8_R_MODULE 1
#undef  CONFIG_NLS_KOI8_U
#define CONFIG_NLS_KOI8_U_MODULE 1
#undef  CONFIG_NLS_UTF8
#define CONFIG_NLS_UTF8_MODULE 1

/*
 * Bluetooth support
 */
#undef  CONFIG_BLUEZ

/*
 * Watchdog
 */
#undef  CONFIG_SOFT_WATCHDOG
#define CONFIG_SOFT_WATCHDOG_MODULE 1

/*
 * Kernel hacking
 */
#undef  CONFIG_DEBUG_KERNEL
#define CONFIG_LOG_BUF_SHIFT (0)

/*
 * Cryptographic options
 */
#define CONFIG_CRYPTO 1
#define CONFIG_CRYPTO_HMAC 1
#undef  CONFIG_CRYPTO_NULL
#define CONFIG_CRYPTO_NULL_MODULE 1
#undef  CONFIG_CRYPTO_MD4
#define CONFIG_CRYPTO_MD4_MODULE 1
#undef  CONFIG_CRYPTO_MD5
#define CONFIG_CRYPTO_MD5_MODULE 1
#undef  CONFIG_CRYPTO_SHA1
#define CONFIG_CRYPTO_SHA1_MODULE 1
#undef  CONFIG_CRYPTO_SHA256
#define CONFIG_CRYPTO_SHA256_MODULE 1
#undef  CONFIG_CRYPTO_SHA512
#define CONFIG_CRYPTO_SHA512_MODULE 1
#undef  CONFIG_CRYPTO_WP512
#define CONFIG_CRYPTO_WP512_MODULE 1
#undef  CONFIG_CRYPTO_DES
#define CONFIG_CRYPTO_DES_MODULE 1
#undef  CONFIG_CRYPTO_BLOWFISH
#define CONFIG_CRYPTO_BLOWFISH_MODULE 1
#undef  CONFIG_CRYPTO_TWOFISH
#define CONFIG_CRYPTO_TWOFISH_MODULE 1
#undef  CONFIG_CRYPTO_SERPENT
#define CONFIG_CRYPTO_SERPENT_MODULE 1
#undef  CONFIG_CRYPTO_AES
#define CONFIG_CRYPTO_AES_MODULE 1
#undef  CONFIG_CRYPTO_CAST5
#define CONFIG_CRYPTO_CAST5_MODULE 1
#undef  CONFIG_CRYPTO_CAST6
#define CONFIG_CRYPTO_CAST6_MODULE 1
#undef  CONFIG_CRYPTO_TEA
#define CONFIG_CRYPTO_TEA_MODULE 1
#undef  CONFIG_CRYPTO_KHAZAD
#define CONFIG_CRYPTO_KHAZAD_MODULE 1
#undef  CONFIG_CRYPTO_ANUBIS
#define CONFIG_CRYPTO_ANUBIS_MODULE 1
#undef  CONFIG_CRYPTO_ARC4
#define CONFIG_CRYPTO_ARC4_MODULE 1
#undef  CONFIG_CRYPTO_DEFLATE
#define CONFIG_CRYPTO_DEFLATE_MODULE 1
#undef  CONFIG_CRYPTO_MICHAEL_MIC
#define CONFIG_CRYPTO_MICHAEL_MIC_MODULE 1
#undef  CONFIG_CRYPTO_TEST
#define CONFIG_CRYPTO_TEST_MODULE 1

/*
 * Library routines
 */
#undef  CONFIG_CRC32
#define CONFIG_CRC32_MODULE 1
#undef  CONFIG_ZLIB_INFLATE
#define CONFIG_ZLIB_INFLATE_MODULE 1
#undef  CONFIG_ZLIB_DEFLATE
#define CONFIG_ZLIB_DEFLATE_MODULE 1
